pub fn some<T, U: Fn(&T) -> bool>(vec: Vec<T>, f: U) -> boolExpand description
The some() method will test whether at least one element in the array passes the test implemented by the provided function
In other words, if there is an element that can make the function ‘f’ return true, then the ‘some’ function will end
use lubricant::array::some;
fn even(ele: &i64) -> bool{
ele % 2 == 0
}
some(
vec![1,2,3],
even
);